@@ -5,7 +5,6 @@
 # published by the Free Software Foundation.
 
 from gallery_dl.extractor import pixeldrain
-import datetime
 
 __tests__ = (
 {
@@ -81,7 +80,7 @@ __tests__ = (
         "success"     : True,
         "title"       : "アルバム",
     },
-    "date"       : datetime.datetime,
+    "date"       : "type:datetime",
     "description": "",
     "detail_href": r"re:/file/(yEK1n2Qc|jW9E6s4h)/info",
     "hash_sha256": r"re:\w{64}",
