@@ -18,6 +18,12 @@ __tests__ = (
     "search_tags": "sfw",
 },
 
+{
+    "#url"     : "https://www.rule34.xyz/sfw",
+    "#comment" : "URL with 'www' subdomain (#8875)",
+    "#class"   : rule34xyz.Rule34xyzTagExtractor,
+},
+
 {
     "#url"  : "https://rule34.xyz/playlists/view/119",
     "#class": rule34xyz.Rule34xyzPlaylistExtractor,
