@@ -9,10 +9,10 @@ from gallery_dl.extractor import imagehosts
 
 __tests__ = (
 {
-    "#url"     : "https://www.silverpic.com/8k562jyix8xq/jxU_0001.JPG.html",
+    "#url"     : "https://www.silverpic.net/8k562jyix8xq/jxU_0001.JPG.html",
     "#category": ("imagehost", "silverpic", "image"),
     "#class"   : imagehosts.SilverpicImageExtractor,
-    "#results" : "https://silverpic.com/img/z7esmp7eor37ssodt4ptpxbzoy/jxU_0001.JPG",
+    "#results" : "https://silverpic.net/img/z7esmp7eor37ssodt4ptpxbzoy/jxU_0001.JPG",
 
     "filename" : "jxU_0001",
     "extension": "jpg",
@@ -21,4 +21,11 @@ __tests__ = (
     "height"   : 5616,
 },
 
+{
+    "#url"     : "https://www.silverpic.com/8k562jyix8xq/jxU_0001.JPG.html",
+    "#category": ("imagehost", "silverpic", "image"),
+    "#class"   : imagehosts.SilverpicImageExtractor,
+    "#results" : "https://silverpic.net/img/z7esmp7eor37ssodt4ptpxbzoy/jxU_0001.JPG",
+},
+
 )
